@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -
 
+from wsgiref.validate import validator
+
+@validator
 def app(environ, start_response):
     """Simplest possible application object"""
     data = 'Hello, World!\n'
     status = '200 OK'
     response_headers = [
         ('Content-type','text/plain'),
-        ('Content-Length', len(data))
+        ('Content-Length', str(len(data)))
     ]
     start_response(status, response_headers)
     return [data]
-
